@@ -2,7 +2,7 @@ package Test::TCP;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use base qw/Exporter/;
 use IO::Socket::INET;
 use Params::Validate ':all';
@@ -19,7 +19,8 @@ sub empty_port {
             Listen    => 5,
             LocalAddr => '127.0.0.1',
             LocalPort => $port,
-            Proto     => 'tcp'
+            Proto     => 'tcp',
+            ReuseAddr => 1,
         );
         return $port if $sock;
     }
@@ -96,7 +97,6 @@ Test::TCP - testing TCP program
 =head1 SYNOPSIS
 
     use Test::TCP;
-    my $port = empty_port();
     test_tcp(
         client => sub {
             my $port = shift;
@@ -110,7 +110,6 @@ Test::TCP - testing TCP program
 
 using other server program
 
-    my $port = empty_port();
     test_tcp(
         client => sub {
             my $port = shift;
@@ -121,7 +120,6 @@ using other server program
         },
     );
 
-
 =head1 DESCRIPTION
 
 Test::TCP is test utilities for TCP/IP program.
@@ -134,7 +132,7 @@ Test::TCP is test utilities for TCP/IP program.
 
     my $port = empty_port();
 
-search empty port
+Get the available port number, you can use.
 
 =item test_tcp
 
@@ -155,7 +153,7 @@ search empty port
 
     wait_port(8080);
 
-Waits for a particular port is available
+Waits for a particular port is available for connect.
 
 =back
 
